@@ -24,8 +24,19 @@
 #' @param token_results TRUE/FALSE indicating whether the results text returned
 #'    should be split into tokens. See the tokenizers package and 
 #'    \code{\link{convert_tokens}} for more details. Defaults to TRUE.
+#' @param convert_sentence TRUE/FALSE indicating if individual lines of PDF file
+#'     should be collapsed into a single large paragraph to perform keyword 
+#'     searching. Default is TRUE
+#' @param split_pattern Regular expression pattern used to split multicolumn 
+#'     PDF files using \code{stringi::stri_split_regex}. 
+#'     Default pattern is "\\p{WHITE_SPACE}{3,}" which can be interpreted as: 
+#'     split based on three or more consecutive white space characters. 
 #' @param full_names TRUE/FALSE indicating if the full file path should be used.
 #'    Default is TRUE, see \code{\link{list.files}} for more details.
+#' @param file_pattern An optional regular expression to select specific file
+#'    names. Only files that match the regular expression will be searched. 
+#'    Defaults to all pdfs, i.e. \code{".pdf"}. See \code{\link{list.files}} 
+#'    for more details.
 #' @param recursive TRUE/FALSE indicating if subdirectories should be searched 
 #'    as well.
 #'    Default is FALSE, see \code{\link{list.files}} for more details.
@@ -55,14 +66,17 @@
 #' 
 #' 
 #' @export
-keyword_directory <- function(directory, keyword, split_pdf = FALSE, 
-                              surround_lines = FALSE,
+keyword_directory <- function(directory, keyword, 
+                              split_pdf = FALSE, surround_lines = FALSE,
                               ignore_case = FALSE, remove_hyphen = TRUE,
-                              token_results = TRUE, full_names = TRUE, 
+                              token_results = TRUE, convert_sentence = TRUE, 
+                              split_pattern = "\\p{WHITE_SPACE}{3,}",
+                              full_names = TRUE, file_pattern = ".pdf",
                               recursive = FALSE, max_search = NULL, ...) {
-  files_dir <- list.files(path = directory, pattern = ".pdf", 
+  
+  files_dir <- list.files(path = directory, pattern = file_pattern, 
                           full.names = full_names, recursive = recursive)
-  file_name <- list.files(path = directory, pattern = ".pdf", 
+  file_name <- list.files(path = directory, pattern = file_pattern, 
                           full.names = FALSE, recursive = recursive)
   
   if(is.null(max_search)) {
@@ -70,7 +84,9 @@ keyword_directory <- function(directory, keyword, split_pdf = FALSE,
       keyword_search(files_dir[xx], keyword = keyword, path = TRUE,
                      split_pdf = split_pdf, surround_lines = surround_lines, 
                      ignore_case = ignore_case, remove_hyphen = remove_hyphen,
-                     token_results = token_results, ...))
+                     token_results = token_results, 
+                     convert_sentence = convert_sentence, 
+                     split_pattern = split_pattern, ...))
   } else {
     files_dir <- files_dir[1:max_search]
     file_name <- file_name[1:max_search]
@@ -78,7 +94,9 @@ keyword_directory <- function(directory, keyword, split_pdf = FALSE,
       keyword_search(files_dir[xx], keyword = keyword, path = TRUE,
                      split_pdf = split_pdf, surround_lines = surround_lines, 
                      ignore_case = ignore_case, remove_hyphen = remove_hyphen,
-                     token_results = token_results, ...))
+                     token_results = token_results, 
+                     convert_sentence = convert_sentence, 
+                     split_pattern = split_pattern, ...))
   }
   
   num_rows <- unlist(lapply(extract_table, nrow))
